==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GitLabSourceListBuilder extends GitLabSourceListFluentImpl<GitLabSourceListBuilder> implements VisitableBuilder<GitLabSourceList,GitLabSourceListBuilder>{
  public GitLabSourceListBuilder() {
    this(false);
  }
  public GitLabSourceListBuilder(Boolean validationEnabled) {
    this(new GitLabSourceList(), validationEnabled);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GitLabSourceList(), validationEnabled);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance) {
    this(fluent, instance, false);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GitLabSourceListBuilder(GitLabSourceList instance) {
    this(instance,false);
  }
  public GitLabSourceListBuilder(GitLabSourceList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  GitLabSourceListFluent<?> fluent;
  Boolean validationEnabled;
  public GitLabSourceList build() {
    GitLabSourceList buildable = new GitLabSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GitLabSourceListBuilder extends GitLabSourceListFluent<GitLabSourceListBuilder> implements VisitableBuilder<GitLabSourceList,GitLabSourceListBuilder>{
  public GitLabSourceListBuilder() {
    this(false);
  }
  public GitLabSourceListBuilder(Boolean validationEnabled) {
    this(new GitLabSourceList(), validationEnabled);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GitLabSourceList(), validationEnabled);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance) {
    this(fluent, instance, false);
  }
  public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new GitLabSourceList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GitLabSourceListBuilder(GitLabSourceList instance) {
    this(instance,false);
  }
  public GitLabSourceListBuilder(GitLabSourceList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new GitLabSourceList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  GitLabSourceListFluent<?> fluent;
  Boolean validationEnabled;
  public GitLabSourceList build() {
    GitLabSourceList buildable = new GitLabSourceList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
